rusty_mos::process::envs

Function envid2env

pub fn envid2env(envid: u32, checkperm: bool) -> Result<usize, KError>
Get the env’s PCB by its id. If checkperm is set, the method will check whether the env just is the current env or the child of it. If not, KError::BadEnv will be returned with a Err wrapper.

Safety

The e get by index SHELL be valid.