rusty_mos::process::envsStruct EnvsWrapper
Source #[repr(align(4096))]
pub struct EnvsWrapper<T>([T; 1024]);
Wrapper to make it aligned to a page.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.